/*
 * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package main

import (
	"testing"

	C "gopkg.in/check.v1"
)

type testWrap struct{}

func TestIndex(t *testing.T) { C.TestingT(t) }
func init() {
	C.Suite(&testWrap{})
}

func (*testWrap) Test_getPackageName(c *C.C) {
	var data = []struct {
		FileName    string
		PackageName string
	}{
		{"libfortran3:amd64.list", "libfortran3"},
	}
	for _, item := range data {
		c.Check(getPackageName(item.FileName), C.Equals, item.PackageName)
	}
}
